package NDash::Groups;

use Mouse;
use FindBin qw($Bin);
use File::Spec;
use File::Basename;
use File::Slurp qw(slurp);
use Carp;

has 'file'          => ( is => 'rw', isa => 'Str' );
has 'groups'        => ( is => 'rw', isa => 'ArrayRef', auto_deref => 1 ); 
has 'group_hosts'   => ( is => 'rw', isa => 'HashRef' );

sub BUILD {
  my ($self, $params) = @_;

  my $file = $params->{file};
  $file = '/etc/ndash/groups' unless -f $file;
  $file = File::Spec->catfile( dirname($Bin), 'conf', 'groups' ) unless -f $file;
  die "Cannot find groups file '$file'" unless -f $file;
  $self->file( $file );

  my @groups = ();
  my %groups = ();
  for my $entry (grep m/\S/, slurp( $file )) {
    chomp $entry;
    my ($group, $hosts) = split /\s*:\s*/, $entry, 2;
    next unless $group && $hosts;
    push @groups, $group;
    $groups{ $group } = [ split /\s*,\s*/, $hosts ];
  }
  $self->groups( \@groups );
  $self->group_hosts( \%groups );
}

sub hosts
{
  my ($self, $group) = @_;
  croak "Missing 'group' argument'" unless $group;
  croak "Invalid group '$group'" unless $self->group_hosts->{$group};
  return wantarray ? @{ $self->group_hosts->{$group} } : $self->group_hosts->{$group};
}

1;

=head1 NAME

NDash::Groups - class modelling NDash groups file

=head1 SYNOPSIS

    use NDash::Groups;

    $ng = NDash::Groups->new;

    @groups = $ng->groups;
    @hosts = $ng->hosts( $group[0] );

=head1 AUTHOR

Gavin Carr L< <<gavin@openfusion.com.au>> >

=head1 COPYRIGHT AND LICENCE

Copyright 2009 Gavin Carr.

This software is free software, licensed under the same terms as Perl itself.

=cut

